package com.yihu.wlyy.web.patient.prescription;

import com.yihu.wlyy.service.app.prescription.PatientPrescriptionPayService;
import com.yihu.wlyy.web.WeixinBaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Created by Reece on 2017/7/28.
 */

@RestController("patientPrescriptionPayController")
@RequestMapping(value = "/patient/prescription/pay", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
@Api(description = "患者端-长处方支付接口")
public class PatientPrescriptionPayController extends WeixinBaseController {

    @Autowired
    private PatientPrescriptionPayService payService;

    /**
     * 患者支付接口
     *
     * @param payInfo
     * @return
     */
    @RequestMapping(value = "/charge", method = RequestMethod.POST)
    @ApiOperation(value = "患者支付接口")
    public String charge(@RequestParam(required = true) @ApiParam(value = "支付数据", name = "payInfo") String payInfo) throws  Exception{
        try {
            JSONObject json = new JSONObject(payInfo);
            JSONObject patientInfo = json.getJSONObject("patientInfo");
            JSONObject expressageInfo = json.getJSONObject("expressageInfo");
            JSONObject prescriptionInfo = json.getJSONObject("prescriptionInfo");
            JSONObject totalAmount = json.getJSONObject("totalAmount");
            payService.charge();
                return error(-1, "获取失败");
        } catch (Exception e) {
            return error(-1, "获取失败");
        }
    }

    /**
     * 患者支付结果查询接口
     *
     * @param outChargeNo
     * @return
     */
    @RequestMapping(value = "/chargeQuery", method = RequestMethod.GET)
    @ApiOperation(value = "患者支付结果查询接口")
    public String chargeQuery(@RequestParam(required = true) @ApiParam(value = "支付应用流水号", name = "outChargeNo") String outChargeNo) throws  Exception{
        try {
            payService.chargeQuery(outChargeNo);
            return error(-1, "获取失败");
        } catch (Exception e) {
            return error(-1, "获取失败");
        }
    }

    /**
     * 支付成功前端页面回调接口
     *
     * @param json
     * @return
     */
    @RequestMapping(value = "/returnUrl", method = RequestMethod.GET)
    @ApiOperation(value = "支付成功前端页面回调接口")
    public String returnUrl(String json) throws Exception{
        try {
            payService.returnUrl();
            return error(-1, "获取失败");
        } catch (Exception e) {
            return error(-1, "获取失败");
        }
    }

    /**
     * 对接方异步回调接口
     *
     * @return
     */
    @RequestMapping(value = "/receiveNotify", method = RequestMethod.GET)
    @ApiOperation(value = "对接方异步回调接口")
    public String receiveNotify(HttpServletRequest request, HttpServletResponse response) throws Exception{
        try {
            payService.receiveNotify();
            return error(-1, "获取失败");
        } catch (Exception e) {
            return error(-1, "获取失败");
        }
    }

}
